# MemberId1


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from haplohub.models.member_id1 import MemberId1

# TODO update the JSON string below
json = "{}"
# create an instance of MemberId1 from a JSON string
member_id1_instance = MemberId1.from_json(json)
# print the JSON string representation of the object
print MemberId1.to_json()

# convert the object into a dict
member_id1_dict = member_id1_instance.to_dict()
# create an instance of MemberId1 from a dict
member_id1_from_dict = MemberId1.from_dict(member_id1_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


